/*******************************************************************************
********************************************************************************

   COPYRIGHT  2004, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   PulsarAPI.h    External definitions for the High Level User Application Programming Interface

   About:         This module contains external definitions for the High Level User Application
                  Programming Interface DLL functions in the AICONS01 project.

   Target:        Win32 Compatible

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 2 $

--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/Pulsar320/pc_src/PulsarAPI/PulsarAPI.h $
 * 
 * 2     8/22/08 3:06p Jpiet
 * Made additions for repeat mode
 * 
 * 1     8/15/08 2:31p Jpiet
 * 
 * 17    5/15/08 4:30p Rmack
 * Changed name of init function to force error from old applications.
 * 
 * 16    5/15/08 2:38p Rmack
 * Updated for 32-bit pulse widths.
 * 
 * 15    5/02/05 8:52a Rmack
 * Dual pulse mode triggers, added new command for lighthead information,
 * separate gated continuous mode of operation.
 * 
 * 14    4/28/05 4:36p Rmack
 * Added new mode specifically for gated continuous.
 * 
 * 13    4/27/05 4:26p Rmack
 * Changed prototype for get_light_data command.
 * 
 * 12    4/27/05 8:45a Rmack
 * Added command to get lighthead data.
 * 
 * 11    2/23/05 5:17p Rmack
 * Supports channel configuration validation, and mixed mode operation.
 * 
 * 10    2/17/05 4:59p Rmack
 * Changed interface to channel configuration commands.
 * 
********************************************************************************
*******************************************************************************/
#ifndef _PULSARAPI_H
#define _PULSARAPI_H
#include <oleauto.h>


// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the PULSARAPI_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// PULSAR_API functions as being imported from a DLL, wheras this DLL sees symbols
// defined with this macro as being exported.  If a non-Microsoft compiler is used the
// PULSAR_API is defined as a blank and no modifications are made to the function interfaces.
#ifdef _MSC_VER
   #ifdef PULSARAPI_EXPORTS
   #define PULSAR_API extern "C" __declspec(dllexport)
   #else
   #define PULSAR_API extern "C" __declspec(dllimport)
   #endif
#else
   #define PULSAR_API
#endif

/* Define name of USB device */
#define API_PULSAR_PRODUCT_NAME            "Ai S1000 Strobe Controller"

/* MPD Standard data type definitions */
#ifndef MPD_TYPES
#define MPD_TYPES
typedef unsigned char  UINT8_T;
typedef unsigned short UINT16_T;
typedef unsigned long  UINT32_T;
typedef char           INT8_T;
typedef short          INT16_T;
typedef long           INT32_T;
typedef unsigned char  BOOLEAN_T;
typedef float          FLOAT32_T;
typedef INT16_T        ERRCODE_T;
#endif


typedef struct
{
   UINT8_T   trigger;
   UINT8_T   rising;
   UINT8_T   mode;
   UINT8_T   reserved_byte;
   UINT32_T  repeat_cnt;
   UINT16_T  delay;
   FLOAT32_T current;
   UINT32_T  width;
   UINT32_T  offtime;
}  API_CHAN_CONFIG_STRUCT_T;              /* 20 bytes */


/* Define possible operating modes */
enum
{
   API_MODE_PULSED,
   API_MODE_REPEAT,
   API_MODE_TIMING_BYPASS,
   API_MODE_INTERNAL_TRIGGER,
   API_NUM_MODE
};

/* Define the drive channel identifiers used with the API interface */
enum
{
   API_CHAN_1 = 1,
   API_CHAN_2,
};

#define API_NUM_CHAN  2

/* Define the trigger input identifiers used with the API interface */
enum
{
   API_TRIG_NONE,
   API_TRIG_1,
   API_TRIG_2,
};

#define API_NUM_TRIG  2

/* Define identifiers used to handle how channel configuration data is used */
#define API_CHAN_CONFIG_DEFAULT        1
#define API_CHAN_CONFIG_ACTIVE         2

/* Define identifiers for diagnostics tests */
enum
{
   API_POWER_TEST,
   API_RAM_TEST,
   API_FLASH_TEST,
   API_EXTIO_TEST,
   API_EEPROM_TEST,
   API_EXT_DAC_TEST,
   API_SCI_TEST,
   API_NUM_TESTS
};

/* Optional diagnostics tests do not normally run on startup of the Pulsar */
/* They require additional hardware beyond the PCB Assembly itself to complete */
/* The optional SCI test requires a serial loopback connector between the external */
/* modular connector and the internal 10-pin header */
#define API_NUM_OPTIONAL_TESTS      1

/* Define bit identifiers for the information returned by the api_get_user_data command */

/* The rotary switch value is returned within a range of 0 to API_MAX_ROTARY */
#define API_MAX_ROTARY     999

/* Each bit is associated with one DIP switch position */
#define API_DIP_MODE0      0x1
#define API_DIP_MODE1      0x2
#define API_DIP_MODE2      0x4
#define API_DIP_MODE3      0x8

/* Each bit is associated with one TRIG input */
#define API_TRIG_IN1       0x1
#define API_TRIG_IN2       0x2

/* Connection state of lighthead, USB, and RS-232 */
#define API_CONN_LH_DETECT 0x1
#define API_CONN_USBDETECT 0x2
#define API_CONN_PCPRESENT 0x4
#define API_CONN_PC_READY  0x8

/* Operating state of power supplies */
#define API_SUPPLY_VIN_ON  0x1
#define API_SUPPLY_LV_ON   0x2
#define API_SUPPLY_HV_ON   0x4

/* Additional expansion general purpose inputs */
#define API_EXP_GPIN1      0x1
#define API_EXP_GPIN2      0x2
#define API_EXP_GPINOUT1   0x4 
#define API_EXP_GPINOUT2   0x8

/* Define possible lighthead types returned by api_get_light_data command */
#define API_SIGNATECH_I    0x01
#define API_SIGNATECH_II   0x02

/* Define analog input identifiers used with api_measure_voltage command */
#define API_AI_VIN_SWMON      0x01
#define API_AI_V_HV_STRINGMON 0x02
#define API_AI_V_LV_STRINGMON 0x03
#define API_AI_VCH1MON        0x04
#define API_AI_VCH2MON        0x05
#define API_AI_VCH3MON        0x06
#define API_AI_VCH4MON        0x07
#define API_AI_GND1           0x08
#define API_AI_SIG1_ID1_MON   0x09
#define API_AI_SIG1_ID2_MON   0x0A
#define API_AI_CH1_DRV_LVL    0x0B
#define API_AI_CH2_DRV_LVL    0x0C
#define API_AI_CH3_DRV_LVL    0x0D
#define API_AI_CH4_DRV_LVL    0x0E
#define API_AI_GND2           0x0F
#define API_AI_10VMON         0x10
#define API_AI_CH1CURRSENS    0x11
#define API_AI_CH2CURRSENS    0x12
#define API_AI_CH3CURRSENS    0x13
#define API_AI_CH4CURRSENS    0x14
#define API_AI_INT_TEMP       0x15
#define API_AI_GND3           0x16
#define API_AI_33VMON         0x17
#define API_AI_5VMON          0x18


/****************************************************************************
   api_get_dll_version()

   Returns the current version number of this software.

   Inputs:     None

   Outputs:    None
   
   Returns:    UINT16_T    ver_info    High byte is major version number
                                       Low byte is minor version number

****************************************************************************/
PULSAR_API UINT16_T __stdcall api_get_dll_version(void);

/****************************************************************************
   api_get_error_name

   About:      Returns the name of the error associated with the code

   Inputs:     ERRCODE_T   ecode       Code to be looked up
               UINT16_T    namelen     Maximum length of name string

   Outputs:    char *      nameptr     Location to place name string

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_error_name(ERRCODE_T ecode,char * nameptr,UINT16_T namelen);

/****************************************************************************
   api_get_error_text

   About:      Returns the text description of the error associated with the code

   Inputs:     ERRCODE_T   ecode       Code to be looked up
               UINT16_T    namelen     Maximum length of text description string

   Outputs:    char *      nameptr     Location to place text description string

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_error_text(ERRCODE_T ecode,char * textptr,UINT16_T textlen);

/****************************************************************************
   api_init

   FOR USB CONNECTIONS ONLY - SEE API_CONNECT FOR TCP/IP CONNECTIONS

   About:      Initializes the connection to a specific Pulsar

   Inputs:     UINT8_T     port         Identifier for device
               INT8_T *    product_name Name of USB device to open
			   INT8_T *    serial_num   Serial number of device to open

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_init(UINT8_T port, INT8_T * product_name, INT8_T * serial_num);

/****************************************************************************
   api_connect

   About:      Initializes the connection to a specific Pulsar

   Inputs:     UINT8_T     port         Identifier for device
               INT8_T *    product_name Name of USB device to open
               INT8_T *    ip_addr      IP address of device to open

   Outputs:    None

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_connect(UINT8_T port, INT8_T * product_name, INT8_T * ip_addr);

/****************************************************************************
   api_get_pulsar_version

   About:      Reads firmware version, hardware version, and serial number
               Each string can be up to 32 characters long.

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    INT8_T *    fw_version  Firmware version
               INT8_T *    hw_version  Hardware version
               INT8_T *    serial_num  Serial number

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_pulsar_version(UINT8_T port, INT8_T * fw_version, INT8_T * hw_version, INT8_T * serial_num);

/****************************************************************************
   api_get_pulsar_ipaddr

   About:      Reads iip configuration settings from the device
               Each string can be up to 32 characters long.

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    INT8_T *    ip_addr	   IP Address
               INT8_T *    subnet	   Subnet Mask
               INT8_T *    gateway	   Gateway
               INT8_T *    mac_addr	   Hardware MAC address

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_pulsar_ipaddr(UINT8_T port, INT8_T * ip_addr, INT8_T * subnet, INT8_T * gateway, INT8_T * mac_addr);

/****************************************************************************
   api_get_status

   About:      Reads status information from the device

   Inputs:     UINT8_T     port        Identifier for device

   Outputs:    None

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_status(UINT8_T port);

/****************************************************************************
   api_run_diags

   About:      Runs one or all of the built in diagnostics

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T     test_num    Desired test number or FF for all

   Outputs:    None

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_run_diags(UINT8_T port, UINT8_T test_num);


/****************************************************************************
   api_get_channel_config

   About:      Gets the configuration data for one drive channel

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T     chan        Identifier for drive channel
               UINT8_T     type        Identifier for which data to get
               
   Outputs:    API_CHAN_CONFIG_STRUCT_T *  config_data
                                       Active channel configuration data

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_channel_config(UINT8_T port, UINT8_T chan, UINT8_T type,
                                               API_CHAN_CONFIG_STRUCT_T *  config_data);
/****************************************************************************
   api_set_channel_config

   About:      Sets the configuration data for one drive channel

   Inputs:     UINT8_T     port        Identifier for device
               UINT8_T     chan        Identifier for drive channel
               UINT8_T     type        Identifier for which data to get
               API_CHAN_CONFIG_STRUCT_T *  config_data
                                       New channel configuration data

   Outputs:    None

   Returns: ERRCODE_T   ecode          Status of command
                                          Zero if successful,
                                          Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_set_channel_config(UINT8_T port, UINT8_T chan, UINT8_T type,
                                               API_CHAN_CONFIG_STRUCT_T *  config_data);


/****************************************************************************
   api_trigger

   About:   Generates a software trigger on the selected trigger channel
   
   Inputs:  UINT8_T   port       Identifier for device
            UINT8_T   trig       Trigger to activate

   Outputs: None
   
   Returns: ERRCODE_T   ecode    Status of command
                                    Zero if successful,
                                    Error code otherwise
  
****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_trigger(UINT8_T port, UINT8_T trig);


/*******************************************************************************
   api_calc_led_temp

   About:   Calculates the expected LED junction temperature based on the
            information stored in the lighthead data structure and the width
            and current information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: FLOAT32_T  *temp        Location to store calculated temperature

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_led_temp(UINT8_T port, UINT8_T ch, 
                                       UINT32_T width, FLOAT32_T current, FLOAT32_T *temp);

/*******************************************************************************
   api_calc_max_width

   About:   Calculates the maximum pulse width for the selected channel based 
            on the information stored in the lighthead data structure and the 
            current information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: UINT32_T   *width       Maximum pulse width in microseconds

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_max_width(UINT8_T port, UINT8_T ch, 
                                        FLOAT32_T current, UINT32_T * width);

/*******************************************************************************
   api_calc_max_current

   About:   Calculates the maximum pulse current for the selected channel based 
            on the information stored in the lighthead data structure and the 
            width information passed.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute LED temperature
            UINT32_T    width       Pulse width in microseconds
   
   Outputs: FLOAT32_T  *current     Maximum pulse current in amps

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_max_current(UINT8_T port, UINT8_T ch, 
                                          UINT32_T width, FLOAT32_T *current);

/*******************************************************************************
   api_calc_supply_voltage

   About:   Calculates the required supply voltage for a given width and current.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute required supply voltage
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: FLOAT32_T  *voltage     Location to store calculated voltage

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_supply_voltage(UINT8_T port, UINT8_T ch, 
                                                    UINT32_T width, FLOAT32_T current, FLOAT32_T *voltage);

/*******************************************************************************
   api_calc_max_freq

   About:   Calculates the maximum frequency allowed for a given width and current.
            This function computes maximum frequency based on the maximum power of
            the power supply and also from the LED cooling equations.  The lower
            value is returned.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to compute maximum frequency
            UINT32_T    width       Pulse width in microseconds
            FLOAT32_T   current     Pulse current in amps
   
   Outputs: UINT16_T   *freq        Location to store calculated frequency

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_calc_max_freq(UINT8_T port, UINT8_T ch, 
                                       UINT32_T width, FLOAT32_T current, UINT16_T *freq);

/*******************************************************************************
   api_measure_drive_current

   About:   Measures the drive current of the selected drive channel.  This 
            function can be used in either pulse or continuous modes.

   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     ch          Channel to measure pulse current
   
   Outputs: FLOAT32_T  *current     Location to store measured pulse current

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_measure_drive_current(UINT8_T port, UINT8_T ch, FLOAT32_T *current);

/*******************************************************************************
   api_measure_voltage

   About:   Measures the voltage of one of the signals monitored by the Pulsar.
   
   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T     id          Identifier for desired voltage to measure
   
   Outputs: FLOAT32_T  *voltage     Location to store measured voltage

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_measure_voltage(UINT8_T port, UINT8_T id, FLOAT32_T *voltage);

/*******************************************************************************
   api_get_user_data

   About:   Gathers various information about the operating state of the Pulsar.

   Inputs:  UINT8_T     port        Identifier for device
   
   Outputs: UINT16_T   *rotary      Value on rotary switches
            UINT8_T    *dip         Value on DIP switches
            UINT8_T    *trigger     State of trigger inputs
            UINT8_T    *connect     Communication connection status
            UINT8_T    *supply      Power supply status
            UINT8_T    *expansion   Expansion status

   Returns: ERRCODE_T ecode         Status of command
                                       Zero if successful,
                                       Error code otherwise

   Notes:   A NULL can be passed for any data values not needed
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_user_data(UINT8_T port,UINT16_T *rotary,UINT8_T *dip,UINT8_T *trigger,
                                       UINT8_T *connect,UINT8_T *supply,UINT8_T *expansion);

/*******************************************************************************
   api_get_light_data

   About:   Gathers information regarding the lighthead type.

   Inputs:  UINT8_T     port        Identifier for device
   
   Outputs: UINT8_T    *sig_model   1 - Signatech I, 2 - Signatech II, 0 - Unknown
            UINT8_T    *sig1_id     Set for Signatech I lightheads
            char       *sig2_pn     Set to part number string for Signatech II

   Returns: ERRCODE_T ecode         Status of command
                                       Zero if successful,
                                       Error code otherwise

********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_light_data(UINT8_T port, UINT8_T *sig_model, UINT8_T *sig1_id, char *sig2_pn, char *sig2_sn);

/*******************************************************************************
   api_set_stored_data

   About:   Saves a block of Ai defined data to EEPROM.
   
   Inputs:  UINT8_T     port        Identifier for device
            UINT8_T    *data        Pointer to data block to be written
            UINT8_T     len         Length of data block to be written
   
   Outputs: None

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_set_stored_data(UINT8_T port, UINT8_T *data, UINT8_T len);

/*******************************************************************************
   api_get_stored_data

   About:   Reads a block of Ai defined data from EEPROM.
   
   Inputs:  UINT8_T     port        Identifier for device            
            UINT8_T     len         Length of data block to read
   
   Outputs: UINT8_T    *data        Pointer to data block to be written

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise
  
********************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_get_stored_data(UINT8_T port, UINT8_T *data, UINT8_T len);



/****************************************************************************
   api_shutdown

   About:      Shuts down the connection to a specific Pulsar

   Inputs:     UINT8_T     port        Communication port to use

   Outputs:    None

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise

****************************************************************************/
PULSAR_API ERRCODE_T __stdcall api_shutdown(UINT8_T port);

 /****************************************************************************
   api_set_configuration

   About:      Shuts down the connection to a specific Pulsar

   Inputs:     UINT8_T     port         Communication port to use
			   UINT8_T *   slew_rate	slew rate setting for device
			   UINT8_T *   diff_trigger	enable differential trigger
			   UINT8_T     limit48v	    enables the 48v output limit
			   UINT8_T	   disable_prot disables signatech 2 protection (future implementation)

   Outputs:    None

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise

****************************************************************************/

PULSAR_API ERRCODE_T __stdcall api_set_configuration(UINT8_T port, UINT8_T* slew_rate, UINT8_T* diff_trigger, UINT8_T limit48v, UINT8_T disable_prot);

/****************************************************************************
   api_get_configuration

   About:      Shuts down the connection to a specific Pulsar
	
   Inputs:     UINT8_T     port				Communication port to use
			   UINT8_T *   pslew_rate		get slew rate setting for device
			   UINT8_T *   pdiff_trigger	get differential trigger status
			   UINT8_T     limit48v			get 48v output limit status
			   UINT8_T	   disable_prot		disables signatech 2 protection (future implementation)

   Outputs:    None

   Returns: ERRCODE_T   ecode       Status of command
                                       Zero if successful,
                                       Error code otherwise

****************************************************************************/

PULSAR_API ERRCODE_T __stdcall api_get_configuration(UINT8_T port, UINT8_T* pslew_rate, UINT8_T* pdiff_trigger, UINT8_T* limit48v, UINT8_T* disable_prot);

long __declspec (dllexport) __stdcall AddLongs_SafeArray(
      SAFEARRAY **psaArray, // the array to use
      long *plSum); // returns the sum of all elements of the array

#endif /* _PULARAPI_H */