/*******************************************************************************
********************************************************************************

   COPYRIGHT  2004, Advanced Illumination, Inc. 

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Advanced Illumination.

   pc_error.h     Definitions for all PC generated error codes.

   About:         This module contains the definitions for all PC generated
                  error codes of the S1000 Strobe Controller in the AICONS01 project.

   Target:        Win32 Compatible

   Written for:   Advanced Illumination, Inc.
                  24 Peavine Drive
                  Rochester, VT 05767
                  http://advancedillumination.com

   Contacts:      John Thrailkill
                  Phone:  (802) 767-3830
                  FAX:    (802) 767-3831
                  jthrailkill@advill.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 8 $

--------------------------------------------------------------------------------
   $Log: /Advanced Illumination/S1000/pc_src/MPDH8USB/pc_error.h $
 * 
 * 8     1/24/06 4:06p Rmack
 * Added functions to get/set lighthead data structure.
 * 
 * 7     4/28/05 4:37p Rmack
 * Added lighthead EEPROM CRC error
 * 
 * 6     2/23/05 4:00p Rmack
 * Added new error codes for PulsarAPI DLL.
 * 
 * 5     2/17/05 4:53p Rmack
 * New error code.
 * 
 * 4     2/09/05 3:47p Rmack
 * New error codes for high level DLL.
 * 
 * 3     1/05/05 8:06a Rmack
 * New error codes for high level DLL.
 * 
 * 2     8/24/04 8:44a Rmack
 * Updated header information.
 * 
 * 1     3/30/04 3:27p Rmack
 * 
********************************************************************************
*******************************************************************************/
#ifndef _PCERROR_H
#define _PCERROR_H



#define NO_ERR                            0

/* Time Toolkit Errors */
#define TKTIME_BASE_ERR                   -10000
#define TKTIME_NO_HIRES_ERR               (TKTIME_BASE_ERR - 0)
#define TKTIME_ABORT_ERR                  (TKTIME_BASE_ERR - 1)

/* USB Host Toolkit Errors */
#define TKUSB_BASE_ERR                    -10100
#define TKUSB_INVALID_PORT_ERR            (TKUSB_BASE_ERR - 0)
#define TKUSB_INVALID_DEVICE_NAME_ERR     (TKUSB_BASE_ERR - 1)
#define TKUSB_WRITE_FAILED_ERR            (TKUSB_BASE_ERR - 2)
#define TKUSB_WRITE_INCOMPLETE_ERR        (TKUSB_BASE_ERR - 3)
#define TKUSB_WRITE_TIMEOUT_ERR           (TKUSB_BASE_ERR - 4)
#define TKUSB_READ_FAILED_ERR             (TKUSB_BASE_ERR - 5)
#define TKUSB_READ_INCOMPLETE_ERR         (TKUSB_BASE_ERR - 6)
#define TKUSB_READ_TIMEOUT_ERR            (TKUSB_BASE_ERR - 7)
#define TKUSB_DATA_NOT_AVAILABLE_ERR      (TKUSB_BASE_ERR - 8)
#define TKUSB_NO_PORT_INIT_ERR            (TKUSB_BASE_ERR - 9)
#define TKUSB_FLUSH_FAILED_ERR            (TKUSB_BASE_ERR - 10)
#define TKUSB_SET_FEATURE_ERR             (TKUSB_BASE_ERR - 11)
#define TKUSB_GET_STRING_ERR              (TKUSB_BASE_ERR - 12)

/* Command Set Toolkit Errors */
#define TKCMDSET_BASE_ERR                 -10200
#define TKCMDSET_NO_ECODE_FILE_ERR        (TKCMDSET_BASE_ERR - 0)
#define TKCMDSET_DEVICE_NOT_FOUND_ERR     (TKCMDSET_BASE_ERR - 1)
#define TKCMDSET_MUTEX_TIMEOUT_ERR        (TKCMDSET_BASE_ERR - 2)
#define TKCMDSET_MUTEX_FAILED_ERR         (TKCMDSET_BASE_ERR - 3)
#define TKCMDSET_INVALID_RESPONSE_ERR     (TKCMDSET_BASE_ERR - 4)
#define TKCMDSET_UNEXPECTED_RESPONSE_ERR  (TKCMDSET_BASE_ERR - 5)
#define TKCMDSET_INVALID_LIGHTHEAD_CRC_ERR (TKCMDSET_BASE_ERR - 6)

/* S Record File Management Toolkit Errors */
#define TKSFILE_BASE_ERR                  -10300
#define TKSFILE_END_OF_FILE_ERR           (TKSFILE_BASE_ERR - 0)
#define TKSFILE_FILE_READ_ERR             (TKSFILE_BASE_ERR - 1)
#define TKSFILE_INVALID_TYPE_ERR          (TKSFILE_BASE_ERR - 2)
#define TKSFILE_BAD_CHECKSUM_ERR          (TKSFILE_BASE_ERR - 3)
#define TKSFILE_INVALID_LENGTH_ERR        (TKSFILE_BASE_ERR - 4)
#define TKSFILE_INVALID_RECORD_ERR        (TKSFILE_BASE_ERR - 5)
#define TKSFILE_INVALID_FILE_ERR          (TKSFILE_BASE_ERR - 6)
#define TKSFILE_FILE_NOT_FOUND_ERR        (TKSFILE_BASE_ERR - 7)
#define TKSFILE_OUTSIDE_BUFFER_ERR        (TKSFILE_BASE_ERR - 8)

/* Cipher Toolkit Errors */
#define TKCIPHER_BASE_ERR                 -10400
#define TKCIPHER_OK                       NO_ERR
#define TKCIPHER_NOT_BLOCK_MULT_ERR       (TKCIPHER_BASE_ERR - 0)

/* CRC Toolkit Errors */
#define TKCRC_BASE_ERR                    -10500
#define TKCRC_OK                          NO_ERR

/* Registry Toolkit Errors */
#define TKREG_BASE_ERR                    -10600
#define TKREG_CANNOT_CREATE_KEY_ERR       (TKREG_BASE_ERR - 0)
#define TKREG_NO_OPEN_KEY_ERR             (TKREG_BASE_ERR - 1)
#define TKREG_STRING_NOT_FOUND_ERR        (TKREG_BASE_ERR - 2)
#define TKREG_STRING_SAVE_ERR             (TKREG_BASE_ERR - 3)

/* COM Port Toolkit Errors */
#define TKCOM_BASE_ERR                    -10700
#define TKCOM_INVALID_PORT_ERR            (TKCOM_BASE_ERR - 0)
#define TKCOM_INVALID_DEVICE_NAME_ERR     (TKCOM_BASE_ERR - 1)
#define TKCOM_WRITE_FAILED_ERR            (TKCOM_BASE_ERR - 2)
#define TKCOM_WRITE_INCOMPLETE_ERR        (TKCOM_BASE_ERR - 3)
#define TKCOM_WRITE_TIMEOUT_ERR           (TKCOM_BASE_ERR - 4)
#define TKCOM_READ_FAILED_ERR             (TKCOM_BASE_ERR - 5)
#define TKCOM_READ_INCOMPLETE_ERR         (TKCOM_BASE_ERR - 6)
#define TKCOM_READ_TIMEOUT_ERR            (TKCOM_BASE_ERR - 7)
#define TKCOM_DATA_NOT_AVAILABLE_ERR      (TKCOM_BASE_ERR - 8)
#define TKCOM_NO_PORT_INIT_ERR            (TKCOM_BASE_ERR - 9)
#define TKCOM_FLUSH_FAILED_ERR            (TKCOM_BASE_ERR - 10)
#define TKCOM_GET_RXSIZE_ERR              (TKCOM_BASE_ERR - 11)
#define TKCOM_DEVICE_NOT_FOUND_ERR        (TKCOM_BASE_ERR - 12)
#define TKCOM_DTR_ERR                     (TKCOM_BASE_ERR - 13)
#define TKCOM_RTS_ERR                     (TKCOM_BASE_ERR - 14)
#define TKCOM_DSR_ERR                     (TKCOM_BASE_ERR - 15)
#define TKCOM_CTS_ERR                     (TKCOM_BASE_ERR - 16)
#define TKCOM_TXBREAK_ERR                 (TKCOM_BASE_ERR - 17)
#define TKCOM_CONFIG_ERR                  (TKCOM_BASE_ERR - 18)

/* Pulsar Application DLL errors */
#define API_BASE_ERR                      -20000
#define API_INVALID_CHAN_ERR              (API_BASE_ERR - 0)
#define API_INVALID_TRIG_ERR              (API_BASE_ERR - 1)
#define API_INVALID_CONFIG_CRC_ERR        (API_BASE_ERR - 2)
#define API_INVALID_STORAGE_LEN_ERR       (API_BASE_ERR - 3)
#define API_INVALID_STORAGE_CRC_ERR       (API_BASE_ERR - 4)
#define API_INVALID_CONFIG_TYPE_ERR       (API_BASE_ERR - 5)
#define API_TRIG_GATE_CONFLICT_ERR        (API_BASE_ERR - 6)
#define API_INVALID_LIGHTHEAD_CRC_ERR     (API_BASE_ERR - 7)


#endif  /* _PCERROR_H */